@@ -161,7 +161,7 @@ __DATA__
 do{ my $x = [
        {
          'additional_cflags' => '-I/opt/local/include/smpeg -I/opt/local/include -I/usr/include -I/usr/X11R6/include',
-         'additional_libs' => '-L/usr/lib -L/usr/X11R6/lib',
+         'additional_libs' => '-L/usr/X11R6/lib -L/usr/lib',
          'build_arch' => 'darwin-thread-multi-2level',
          'build_cc' => '/usr/bin/clang',
          'build_os' => 'darwin',
@@ -169,15 +169,15 @@ do{ my $x = [
                              'buildtype' => 'use_config_script',
                              'prefix' => '/opt/local',
                              'script' => 'sdl-config',
-                             'title' => 'Already installed SDL ver=1.2.15 path=/opt/local'
+                             'title' => 'Already installed SDL ver=1.2.16 path=/opt/local'
                            },
-         'build_prefix' => 'sharedir/1.446_bfe6397d',
+         'build_prefix' => 'sharedir/1.446_46883e13',
          'config' => {
                        'ld_paths' => [],
                        'ld_shared_libs' => [
                                              '/usr/lib/libpthread.dylib',
-                                             '/opt/local/lib/libz.1.2.11.dylib',
-                                             '/opt/local/lib/libjpeg.9.dylib',
+                                             '/usr/lib/libz.1.1.3.dylib',
+                                             '/opt/local/lib/libjpeg.8.2.2.dylib',
                                              '/opt/local/lib/libtiff.5.dylib',
                                              '/usr/X11R6/lib/libpng.3.dylib',
                                              '/opt/local/lib/libogg.0.dylib',
@@ -190,16 +190,16 @@ do{ my $x = [
                                              '/opt/local/lib/libgmodule-2.0.0.dylib',
                                              '/opt/local/lib/libglib-2.0.0.dylib',
                                              '/usr/X11R6/lib/libfontconfig.1.4.4.dylib',
-                                             '/opt/local/lib/libexpat.1.6.11.dylib'
+                                             '/usr/lib/libexpat.1.5.2.dylib'
                                            ],
                        'ld_shlib_map' => {
-                                           'expat' => '/opt/local/lib/libexpat.1.6.11.dylib',
+                                           'expat' => '/usr/lib/libexpat.1.5.2.dylib',
                                            'fontconfig' => '/usr/X11R6/lib/libfontconfig.1.4.4.dylib',
                                            'freetype' => '/usr/X11R6/lib/libfreetype.6.dylib',
                                            'glib' => '/opt/local/lib/libglib-2.0.0.dylib',
                                            'gmodule' => '/opt/local/lib/libgmodule-2.0.0.dylib',
                                            'gobject' => '/opt/local/lib/libgobject-2.0.0.dylib',
-                                           'jpeg' => '/opt/local/lib/libjpeg.9.dylib',
+                                           'jpeg' => '/opt/local/lib/libjpeg.8.2.2.dylib',
                                            'ogg' => '/opt/local/lib/libogg.0.dylib',
                                            'pango' => '/opt/local/lib/libpango-1.0.0.dylib',
                                            'pangoft2' => '/opt/local/lib/libpangoft2-1.0.0.dylib',
@@ -208,7 +208,7 @@ do{ my $x = [
                                            'tiff' => '/opt/local/lib/libtiff.5.dylib',
                                            'vorbis' => '/opt/local/lib/libvorbis.0.dylib',
                                            'vorbisfile' => '/opt/local/lib/libvorbisfile.3.dylib',
-                                           'z' => '/opt/local/lib/libz.1.2.11.dylib'
+                                           'z' => '/usr/lib/libz.1.1.3.dylib'
                                          }
                      },
          'script' => 'sdl-config'
